const generateOopTsTemplate = (modelName, isMongo, isMysql) => {
    let template;
    const capitalizeFirstLetter = (str) => {
        return str.charAt(0).toUpperCase() + str.slice(1);
    };
    if (isMongo) {
        template = `import { Schema, Document, model } from "mongoose";

export interface I${capitalizeFirstLetter(modelName)} extends Document {
  
}

const ${capitalizeFirstLetter(modelName)}Schema = new Schema(
    {

    }
);

export const ${capitalizeFirstLetter(modelName)}Model = model<I${capitalizeFirstLetter(modelName)}>("${modelName.charAt(0) !== "s" ? `${modelName}s` : modelName}", ${capitalizeFirstLetter(modelName)}Schema);
`;
    }
    if (isMysql) {
        template = `
import { sequelizeInstance } from "@/configs/db.configs";
import { DataTypes } from "sequelize";

export const ${capitalizeFirstLetter(modelName)} = sequelizeInstance.define("${modelName}", {
  id: {
    type: DataTypes.INTEGER,
    allowNull: false,
    primaryKey: true,
    autoIncrement: true,
  },
});
`;
    }
    if (!isMongo && !isMysql) {
        template = ``;
    }
    return template;
};
const generateOopJsTemplate = (modelName, isMongo, isMysql) => {
    let template;
    const capitalizeFirstLetter = (str) => {
        return str.charAt(0).toUpperCase() + str.slice(1);
    };
    if (isMongo) {
        template = `
const { Schema, model } = require("mongoose");

const ${capitalizeFirstLetter(modelName)}Schema = new Schema(
    {

    }
);

const ${capitalizeFirstLetter(modelName)}Model = model("${modelName.charAt(0) !== "s" ? `${modelName}s` : modelName}", ${capitalizeFirstLetter(modelName)}Schema);

module.exports = { ${capitalizeFirstLetter(modelName)}Model }
`;
    }
    if (isMysql) {
        template = `
const { sequelizeInstance } = require("../../../configs/db.configs");
const { DataTypes } = require("sequelize");

const User = sequelizeInstance.define("user", {
  id: {
    type: DataTypes.INTEGER,
    allowNull: false,
    primaryKey: true,
    autoIncrement: true,
  },
});

module.exports = { ${capitalizeFirstLetter(modelName)} };
`;
    }
    if (!isMongo && !isMysql) {
        template = ``;
    }
    return template;
};
const generateFnTsTemplate = (modelName, isMongo, isMysql) => {
    let template;
    const capitalizeFirstLetter = (str) => {
        return str.charAt(0).toUpperCase() + str.slice(1);
    };
    if (isMongo) {
        template = `
import { Schema, Document, model } from "mongoose";

export interface I${capitalizeFirstLetter(modelName)} extends Document {
  
}

const ${capitalizeFirstLetter(modelName)}Schema = new Schema(
    {

    }
);

export const ${capitalizeFirstLetter(modelName)}Model = model<I${capitalizeFirstLetter(modelName)}>("${modelName.charAt(0) !== "s" ? `${modelName}s` : modelName}", ${capitalizeFirstLetter(modelName)}Schema);
`;
    }
    if (isMysql) {
        template = `
import { sequelizeInstance } from "@/configs/db.configs";
import { DataTypes } from "sequelize";

export const ${capitalizeFirstLetter(modelName)} = sequelizeInstance.define("${modelName}", {
  id: {
    type: DataTypes.INTEGER,
    allowNull: false,
    primaryKey: true,
    autoIncrement: true,
  },
});
`;
    }
    if (!isMongo && !isMysql) {
        template = ``;
    }
    return template;
};
const generateFnJsTemplate = (modelName, isMongo, isMysql) => {
    let template;
    const capitalizeFirstLetter = (str) => {
        return str.charAt(0).toUpperCase() + str.slice(1);
    };
    if (isMongo) {
        template = `
const { Schema, model } = require("mongoose");

const ${capitalizeFirstLetter(modelName)}Schema = new Schema(
    {

    }
);

const ${capitalizeFirstLetter(modelName)}Model = model("${modelName.charAt(0) !== "s" ? `${modelName}s` : modelName}", ${capitalizeFirstLetter(modelName)}Schema);

module.exports = { ${capitalizeFirstLetter(modelName)}Model };
`;
    }
    if (isMysql) {
        template = `
const { sequelizeInstance } = require("../../../configs/db.configs");
const { DataTypes } = require("sequelize");

const User = sequelizeInstance.define("user", {
  id: {
    type: DataTypes.INTEGER,
    allowNull: false,
    primaryKey: true,
    autoIncrement: true,
  },
});

module.exports = { ${capitalizeFirstLetter(modelName)} };
`;
    }
    if (!isMongo && !isMysql) {
        template = ``;
    }
    return template;
};
export { generateFnJsTemplate, generateFnTsTemplate, generateOopJsTemplate, generateOopTsTemplate, };
